.container.svelte-giydt1 img{width:100%;height:100%}.container.selected.svelte-giydt1.svelte-giydt1{border-color:var(--border-color-accent)}.container.table.svelte-giydt1.svelte-giydt1{margin:0 auto;border:2px solid var(--border-color-primary);border-radius:var(--radius-lg);overflow:hidden;width:var(--size-20);height:var(--size-20);object-fit:cover}.container.gallery.svelte-giydt1.svelte-giydt1{height:var(--size-20);max-height:var(--size-20);object-fit:cover}.container.svelte-giydt1 img.svelte-giydt1{object-fit:cover}.image-container.svelte-mdifpc{height:100%}.image-container.svelte-mdifpc img,button.svelte-mdifpc{width:var(--size-full);height:var(--size-full);object-fit:scale-down;display:block;border-radius:var(--radius-lg)}.selectable.svelte-mdifpc{cursor:crosshair}.image-frame.svelte-1mw9bca img{width:var(--size-full);height:var(--size-full);object-fit:scale-down}.image-frame.svelte-1mw9bca{width:100%;height:100%}.upload-container.svelte-1mw9bca{height:100%;flex-shrink:1;max-height:100%}.image-container.svelte-1mw9bca{display:flex;height:100%;flex-direction:column;justify-content:center;align-items:center;max-height:100%}
